@@ -11,7 +11,7 @@
 #' cluster memberships for new data.
 #'
 #' @templateVar id clust.cmeans
-#' @template section_dictionary_learner
+#' @template learner
 #' @template example
 #'
 #' @export
@@ -21,48 +21,39 @@ LearnerClustCMeans = R6Class("LearnerClustCMeans",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ParamSet$new(
-        params = list(
-          ParamUty$new(
-            id = "centers", tags = c("required", "train"), default = 2L,
-            custom_check = function(x) {
-              if (test_data_frame(x)) {
-                return(TRUE)
-              } else if (test_int(x)) {
-                assert_true(x >= 1L)
-              } else {
-                return("`centers` must be integer or data.frame with initial cluster centers")
-              }
+      ps = ps(
+        centers = p_uty(tags = c("required", "train"), default = 2L,
+          custom_check = function(x) {
+            if (test_data_frame(x)) {
+              return(TRUE)
+            } else if (test_int(x)) {
+              assert_true(x >= 1L)
+            } else {
+              return("`centers` must be integer or data.frame with initial cluster centers")
             }
-          ),
-          ParamInt$new(id = "iter.max", lower = 1L, default = 100L, tags = "train"),
-          ParamLgl$new(id = "verbose", default = FALSE, tags = "train"),
-          ParamFct$new(
-            id = "dist", levels = c("euclidean", "manhattan"),
-            default = "euclidean", tags = "train"),
-          ParamFct$new(
-            id = "method", levels = c("cmeans", "ufcl"),
-            default = "cmeans", tags = "train"),
-          ParamDbl$new(id = "m", lower = 1L, default = 2L, tags = "train"),
-          ParamDbl$new(id = "rate.par", lower = 0L, upper = 1L, tags = "train"),
-          ParamUty$new(
-            id = "weights", default = 1L,
-            custom_check = function(x) {
-              if (test_numeric(x)) {
-                if (sum(sign(x)) == length(x)) {
-                  return(TRUE)
-                } else {
-                  return("`weights` must contain only positive numbers")
-                }
-              } else if (test_count(x)) {
+          }
+        ),
+        iter.max = p_int(lower = 1L, default = 100L, tags = "train"),
+        verbose = p_lgl(default = FALSE, tags = "train"),
+        dist = p_fct(levels = c("euclidean", "manhattan"), default = "euclidean", tags = "train"),
+        method = p_fct(levels = c("cmeans", "ufcl"), default = "cmeans", tags = "train"),
+        m = p_dbl(lower = 1L, default = 2L, tags = "train"),
+        rate.par = p_dbl(lower = 0L, upper = 1L, tags = "train"),
+        weights = p_uty(default = 1L, custom_check = function(x) {
+            if (test_numeric(x)) {
+              if (sum(sign(x)) == length(x)) {
                 return(TRUE)
               } else {
-                return("`weights` must be positive numeric vector or a single positive number")
+                return("`weights` must contain only positive numbers")
               }
-            },
-            tags = "train"),
-          ParamUty$new(id = "control", tags = "train")
-        )
+            } else if (test_count(x)) {
+              return(TRUE)
+            } else {
+              return("`weights` must be positive numeric vector or a single positive number")
+            }
+          },
+          tags = "train"),
+        control = p_uty(tags = "train")
       )
       # add deps
       ps$add_dep("rate.par", "method", CondEqual$new("ufcl"))
@@ -75,7 +66,8 @@ LearnerClustCMeans = R6Class("LearnerClustCMeans",
         predict_types = c("partition", "prob"),
         param_set = ps,
         properties = c("partitional", "fuzzy", "complete"),
-        packages = "e1071"
+        packages = "e1071",
+        label = "Fuzzy C-Means Clustering Learner"
       )
     }
   ),
