@@ -6,32 +6,37 @@
 #' @importFrom R6 R6Class
 #' @importFrom clue cl_predict
 #' @importFrom clusterCrit intCriteria
-#' @importFrom stats model.frame terms
+#' @importFrom stats model.frame terms predict runif
 "_PACKAGE"
 
 register_mlr3 = function() {
 
+  # reflections
   x = utils::getFromNamespace("mlr_reflections", ns = "mlr3")
 
-  if (length(x$task_types[list("clust"), on = "type", which = TRUE, nomatch = NULL]) == 0L) {
-    x$task_types = setkeyv(rbind(x$task_types, rowwise_table(
-      ~type, ~package, ~task, ~learner, ~prediction, ~measure,
-      "clust", "mlr3cluster", "TaskClust", "LearnerClust", "PredictionClust", "MeasureClust"
-    )), "type")
-    x$task_col_roles$clust = x$task_col_roles$regr
-    x$task_properties$clust = x$task_properties$regr
-    x$learner_properties$clust = c(
-      "missings", "partitional", "hierarchical", "exclusive",
-      "overlapping", "fuzzy", "complete", "partial"
-    )
-    x$measure_properties$clust = x$measure_properties$regr
-    x$learner_predict_types$clust = list(partition = "partition", prob = c("partition", "prob"))
-    x$default_measures$clust = "clust.dunn"
-  }
+  # task
+  x$task_types = x$task_types[!"clust"]
+  x$task_types = setkeyv(rbind(x$task_types, rowwise_table(
+    ~type,    ~package,       ~task,        ~learner,       ~prediction,        ~prediction_data,       ~measure,
+    "clust",  "mlr3cluster",  "TaskClust",  "LearnerClust", "PredictionClust",  "PredictionDataClust",  "MeasureClust"
+  ), fill = TRUE), "type")
 
+  x$task_col_roles$clust = x$task_col_roles$regr
+  x$task_properties$clust = x$task_properties$regr
+  x$learner_properties$clust = c("missings", "partitional", "hierarchical", "exclusive", "overlapping", "fuzzy", "complete", "partial")
+
+  # measure
+  x$measure_properties$clust = x$measure_properties$regr
+
+  # learner
+  x$learner_predict_types$clust = list(partition = "partition", prob = c("partition", "prob"))
+  x$default_measures$clust = "clust.dunn"
+
+  # tasks
   x = utils::getFromNamespace("mlr_tasks", ns = "mlr3")
   x$add("usarrests", load_task_usarrests)
 
+  # learners
   x = utils::getFromNamespace("mlr_learners", ns = "mlr3")
   x$add("clust.featureless", LearnerClustFeatureless)
   x$add("clust.kmeans", LearnerClustKMeans)
@@ -52,6 +57,7 @@ register_mlr3 = function() {
   x$add("clust.meanshift", LearnerClustMeanShift)
   x$add("clust.hclust", LearnerClustHclust)
 
+  # measures
   x = utils::getFromNamespace("mlr_measures", ns = "mlr3")
   x$add("clust.db", MeasureClustInternal, name = "db")
   x$add("clust.dunn", MeasureClustInternal, name = "dunn")
@@ -60,9 +66,10 @@ register_mlr3 = function() {
   x$add("clust.wss", MeasureClustInternal, name = "wss")
 }
 
-.onLoad = function(libname, pkgname) { # nolint
-  # nocov start
+.onLoad = function(libname, pkgname) {
   backports::import(pkgname)
 
   register_mlr3()
-} # nocov end
+}
+
+leanify_package()
